# di: pythonic dependency injection

[![codecov](https://codecov.io/gh/adriangb/di/branch/main/graph/badge.svg?token=A0FXC8B93Y)](https://codecov.io/gh/adriangb/di)
![Workflow](https://github.com/adriangb/di/actions/workflows/workflow.yaml/badge.svg)
[![di](https://snyk.io/advisor/python/di/badge.svg)](https://snyk.io/advisor/python/di)

⚠️ This project is a WIP. Until there is a 1.X.Y release, expect breaking changes. ⚠️

For more information, see our [docs].

[docs]: https://www.adriangb.com/di/

See this release on GitHub: [v0.38.0](https://github.com/adriangb/di/releases/tag/0.38.0)
